import Vue from 'vue';
import VueI18n from 'vue-i18n';
Vue.use(VueI18n);

const messages = {
    'en': {
        Login: {
            loginHeader: 'Login',
            registerBtn: 'Register',
            username: 'username',
            password: 'password',
            loginBtn: 'login',
            passwordHint: 'At Least 8 characters',
            required: 'Required',
            min8Character: 'Min 8 Characters',
            usernameAlert: 'please enter username',
            passwordAlert: 'please enter password',
            errorUserNotFound: 'User not found',
            errorIncorrectPassword: 'Incorrect Password',
            changePassword: 'Change Password?'
        },
        Register: {
            registerHeader: 'Register',
            loginBtn: 'login',
            username: 'username',
            password: 'password',
            repeatPassword: 'repeat password',
            registerBtn: 'Register And Login',
            required: 'Required',
            min8Character: 'Min 8 Characters',
            matchPass: "password and repeat passwords must be the same",
            usernameAlert: 'please enter username',
            firstPassAlert: 'please enter password',
            secondPassAlert: 'please enter password',
            error403: 'Username already exists',
            loadingText: 'creating user',
            userCreated: 'user has been Created'
        },
        AppHeader: {
            appName: 'Karname',
        },
        AppFooter: {
            appLang: 'en',
        },
        ChangePassword: {
            formHeader: 'change password',
            username: 'username',
            usernameAlert: 'please enter username',
            oldPassword: 'old password',
            oldPasswordAlert: 'please enter old password',
            newPassword: 'new password',
            newPasswordAlert: 'please enter new password',
            matchPass: 'old password and new password should not be the same',
            required: 'Required',
            min8Character: 'Min 8 Characters',
            changePasswordBtn: 'change',
            loadingText: 'changing password',
            NotFoundUser: 'user not found',
            CheckPassError: 'incorrect old password',
            SuccessChangePass: 'Password Successfully changed',
            internalServerError: 'internal server error'
        }


    },
    'fa': {
        Login: {
            loginHeader: 'ورود کاربر',
            registerBtn: 'ثبت نام',
            username: 'نام کاربری',
            password: 'رمز ورود',
            loginBtn: 'ورود',
            passwordHint: 'حداقل 8 کاراکتر',
            required: 'مورد نیاز',
            min8Character: 'حداقل 8 کاراکتر',
            usernameAlert: 'لطفا نام کاربری را وارد نمایید',
            passwordAlert: 'لطفا رمز ورود را وارد نمایید',
            errorUserNotFound: 'کاربر یافت نشد',
            errorIncorrectPassword: 'رمز نادرست',
            changePassword: 'تغییر رمز؟'
        },
        Register: {
            registerHeader: 'ثبت نام کاربر',
            loginBtn: 'ورود',
            username: 'نام کاربری',
            password: 'رمز ورود',
            repeatPassword: 'تکرار رمز ورود',
            registerBtn: 'ثبت نام و ورود',
            required: 'مورد نیاز',
            min8Character: 'حداقل 8 کاراکتر',
            matchPass: "رمز عبور و تکرار آن باید مشابه باشند",
            usernameAlert: 'لطفا نام کاربری را وارد نمایید',
            firstPassAlert: 'لطفا رمز را وارد نمایید',
            secondPassAlert: 'لطفا رمز را وارد نمایید',
            error403: 'نام کاربری وجود دارد',
            loadingText: 'در حال ایجاد کاربر',
            userCreated: 'کاربر ایجاد شد'
        },
        AppHeader: {
            appName: 'کارنامه',
        },
        AppFooter: {
            appLang: 'فا',
        },
        ChangePassword: {
            formHeader: 'تغییر رمز',
            username: 'نام کاربری',
            usernameAlert: 'لطفا نام کاربری را وارد نمایید',
            oldPassword: 'رمز فعلی',
            oldPasswordAlert: 'لطفا رمز فعلی را وارد نمایید',
            newPassword: 'رمز جدید',
            newPasswordAlert: 'لطفا رمز جدید را وارد نمایید',
            matchPass: 'رمز فعلی و رمز جدید نباید یکسان باشند',
            required: 'مورد نیاز',
            min8Character: 'حداقل 8 کاراکتر',
            changePasswordBtn: 'تغییر رمز',
            loadingText: 'در حال تغییر رمز',
            NotFoundUser: 'کاربر یافت نشد',
            CheckPassError: 'رمز فعلی نادرست می باشد',
            SuccessChangePass: 'رمز کاربر با موفقیت تغییر یافت',
            internalServerError: 'خطا در سرور'
        }

    }
};

const i18n = new VueI18n({
    locale: 'en', // set locale    
    fallbackLocale: 'fa', // set fallback locale    
    messages, // set locale messages
});

export default i18n;